@@ -1,5 +1,3 @@
-#ifndef breezetransitionwidget_h
-#define breezetransitionwidget_h
 //////////////////////////////////////////////////////////////////////////////
 // breezetransitionwidget.h
 // stores event filters and maps widgets to transitions for transitions
@@ -10,6 +8,8 @@
 // SPDX-License-Identifier: MIT
 //////////////////////////////////////////////////////////////////////////////
 
+#pragma once
+
 #include "breeze.h"
 #include "breezeanimation.h"
 
@@ -243,5 +243,3 @@ private:
 };
 
 }
-
-#endif
