@@ -14,7 +14,7 @@ namespace Breeze
 //_________________________________________________
 QStyle *StylePlugin::create(const QString &key)
 {
-    if (key.toLower() == QStringLiteral("breeze")) {
+    if (key.compare(QLatin1String("breeze"), Qt::CaseInsensitive) == 0) {
         return new Style;
     }
     return nullptr;
